<#assign import_block>
import EChart from 'echarts';
import { ResizeSensor } from 'css-element-queries';
</#assign>
<#ibizinclude>
../@MACRO/CONTROL/CONTROL_HEADER.tsx.ftl
</#ibizinclude>

    /**
     * 获取多项数据
     *
     * @returns {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getDatas(): any[] {
        return [];
    }

    /**
     * 获取单项树
     *
     * @returns {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getData(): any {
        return null;
    }

    /**
     * url
     *
     * @private
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private url: string = '<#ibizinclude>../@MACRO/CONTROL/URL.tsx.ftl</#ibizinclude>';

    /**
     * 图表对象
     *
     * @private
     * @type {(EChart.ECharts | null)}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private chart: EChart.ECharts | null = null;

    /**
     * 监控dom节点大写
     *
     * @private
     * @type {(ResizeSensor | null)}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private resize: ResizeSensor | null = null;

    /**
     * 绘制出数据
     *
     * @private
     * @param {*} data
     * @returns {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    private renderData(data: any): any {
        if (data.series) {

            //区域图分析
            if (data.series.length) {
                if (Object.is(data.series[0].type, 'area')) {

                    //如果series是数组的话
                    for (let i in data.series) {
                        data.series[i].type = 'line';
                        data.series[i].areaStyle = {};
                        Object.assign(data.series[i].areaStyle, { normal: {} });
                    }
                    return data;
                }
            } else {
                if (Object.is(data.series.type, 'area')) {
                    data.series.type = 'line';
                    data.series.areaStyle = {};
                    Object.assign(data.series.areaStyle, { normal: {} });
                    return data;
                }
            }

            //雷达图分析
            if (data.series.length) {
                if (Object.is(data.series[0].type, 'radar')) {

                    //1.找到每个角的最大值
                    let max: number = 0;

                    //获得每个角的数据
                    let arrs: Array<any> = [];
                    for (let i in data.series) {
                        arrs.push(data.series[i].data);
                    }
                    const lastarrs: Array<any> = arrs[0].map(function (col: any, i: string | number) {
                        return arrs.map(function (row) {
                            return row[i];
                        })
                    });
                    let maxs: any[] = [];
                    for (let j in lastarrs) {
                        max = lastarrs[j][0];
                        for (let k in lastarrs[j]) {
                            if (max < lastarrs[j][k]) {
                                max = lastarrs[j][k];
                            }
                        }
                        maxs.push(max);
                    }

                    // x轴数据转化成indicator数据
                    let indicatorArr: Array<any> = [];
                    for (let i in data.xAxis.data) {
                        const key: any = i;
                        for (let j in maxs) {
                            if (i === j) {
                                indicatorArr.push({ name: data.xAxis.data[key], max: maxs[key] });
                            }
                        }
                    }
                    data.radar.indicator = [];
                    if (Array.isArray(indicatorArr)) {
                        data.radar.indicator = [...indicatorArr];
                    }
                    data.xAxis = null;

                    // 设置series的data数据
                    for (let i in data.series) {
                        const valueArray = data.series[i].data;
                        const name = data.series.name;
                        data.series[i].data = [];
                        data.series[i].data.push({ name: name, value: valueArray });
                    }
                }
            }
        }
        return data;
    }

    /**
     * 数据加载
     *
     * @param {*} [arg={}]
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public load(arg: any = {}): void {

        const parentdata: any = {};
        this.$emit('beforeload', parentdata);
        Object.assign(arg, parentdata);

        const post: Promise<any> = this.$http.post(this.url + 'search', arg, true);
        post.then((response: any) => {
            if (!response.status || response.status !== 200) {
                if (response.errorMessage) {
                    this.$Notice.error({ title: '错误', desc: response.errorMessage });
                }
                return;
            }
            const { data: _data } = response;
            if (_data.records.length !== 1) {
                return;
            }
            const option = this.renderData(_data.records[0]);
            if (this.chart) {
                this.chart.setOption(option);
            }

        }, (response: any) => {
            if (response && response.status === 401) {
                return;
            }
            this.$Notice.error({ title: '错误', desc: response.errorMessage });
        });
    }

    /**
     * vue 生命周期
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public mounted() {
        const el: Element | any = this.$el;
        this.chart = EChart.init(el);
        this.resize = new ResizeSensor(this.$el, () => {
            if (this.chart) {
                this.chart.resize();
            }
        });
        if (this.viewState) {
            this.viewStateEvent = this.viewState.subscribe(({ tag, action, data }) => {
                if (!Object.is(tag, this.name)) {
                    return;
                }
                if (Object.is('load', action)) {
                    this.load(data);
                }
            });
        }
    }

    /**
     * vue 生命周期
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public destroyed() {
        if (this.resize) {
            this.resize.detach();
        }
    }

    /**
     * 绘制内容
     *
     * @returns
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public render() {
        return <div  class='${ctrl.name}'></div>;
    }


<#ibizinclude>
../@MACRO/CONTROL/CONTROL_BOTTOM.tsx.ftl
</#ibizinclude>
